polaris-studio
==========

The polaris-studio package is th Python gateway for all things Polaris. The package is
divided in several submodules varying from data preparation to result analysis and is
the source of truth for the data model required by Polaris.

For the package's full description and documentation, see: https://polaris.taps.anl.gov/polaris/index.html


